@@ -263,7 +263,7 @@ async def write_file(request):
             }
         else:
             file = open(file_path, "wb")
-            file.write(base64.b64decode(message["data"]))
+            file.write(base64.b64decode(reqest["data"]))
             file.close()
             response = {
                 "status": "success", 
@@ -400,7 +400,7 @@ async def connect_and_consume_mythic_rpc(main_config: dict, debug):
         )
         result = await asyncio.wait_for(task, None)
     except Exception as e:
-        print_flush("Exception in connect_and_consume_rpc .consume: {}".format(str(e)))
+        print_flush("Exception in connect_and_consume_mythic_rpc .consume: {}".format(str(e)))
 
 
 async def mythic_service(debug: bool):
@@ -459,9 +459,10 @@ async def mythic_service(debug: bool):
         if debug:
             print_flush("Creating task for connect_and_consume_rpc from mythic_service")
         task4 = asyncio.ensure_future(connect_and_consume_rpc(main_config, debug))
+        task5 = asyncio.ensure_future(connect_and_consume_mythic_rpc(main_config, debug))
         if debug:
             print_flush("Waiting for all tasks to finish in mythic_service")
-        result = await asyncio.gather(task, task4)
+        result = await asyncio.gather(task, task4, task5)
     except Exception as e:
         print_flush("Exception in mythic_service: " + str(traceback.format_exc()))
     
